+{
   upper_before_lower => 1,
   entry => <<'ENTRY', # for DUCET v5.2.0
010B      ; [.124F.0020.0002.010B] # LATIN SMALL LETTER C WITH DOT ABOVE
0063 0307 ; [.124F.0020.0002.010B] # LATIN SMALL LETTER C WITH DOT ABOVE
010A      ; [.124F.0020.0008.010A] # LATIN CAPITAL LETTER C WITH DOT ABOVE
0043 0307 ; [.124F.0020.0008.010A] # LATIN CAPITAL LETTER C WITH DOT ABOVE
0121      ; [.12AF.0020.0002.0121] # LATIN SMALL LETTER G WITH DOT ABOVE
0067 0307 ; [.12AF.0020.0002.0121] # LATIN SMALL LETTER G WITH DOT ABOVE
0120      ; [.12AF.0020.0008.0120] # LATIN CAPITAL LETTER G WITH DOT ABOVE
0047 0307 ; [.12AF.0020.0008.0120] # LATIN CAPITAL LETTER G WITH DOT ABOVE
0067 0127 ; [.12D2.0020.0002.0067] # <LATIN SMALL LETTER G, LATIN SMALL LETTER H WITH STROKE>
0067 0126 ; [.12D2.0020.0007.0067][.0000.0000.0002.0000] # <LATIN SMALL LETTER G, LATIN CAPITAL LETTER H WITH STROKE>
0047 0127 ; [.12D2.0020.0007.0047][.0000.0000.0008.0000] # <LATIN CAPITAL LETTER G, LATIN SMALL LETTER H WITH STROKE>
0047 0126 ; [.12D2.0020.0008.0047] # <LATIN CAPITAL LETTER G, LATIN CAPITAL LETTER H WITH STROKE>
0067 0068 0335 ; [.12D2.0020.0002.0067] # <LATIN SMALL LETTER G, LATIN SMALL LETTER H, COMBINING SHORT STROKE OVERLAY>
0067 0048 0335 ; [.12D2.0020.0007.0067][.0000.0000.0002.0000] # <LATIN SMALL LETTER G, LATIN CAPITAL LETTER H, COMBINING SHORT STROKE OVERLAY>
0047 0068 0335 ; [.12D2.0020.0007.0047][.0000.0000.0008.0000] # <LATIN CAPITAL LETTER G, LATIN SMALL LETTER H, COMBINING SHORT STROKE OVERLAY>
0047 0048 0335 ; [.12D2.0020.0008.0047] # <LATIN CAPITAL LETTER G, LATIN CAPITAL LETTER H, COMBINING SHORT STROKE OVERLAY>
0127      ; [.12EB.0020.0002.0127] # LATIN SMALL LETTER H WITH STROKE
0068 0335 ; [.12EB.0020.0002.0127] # LATIN SMALL LETTER H WITH STROKE
0126      ; [.12EB.0020.0008.0126] # LATIN CAPITAL LETTER H WITH STROKE
0048 0335 ; [.12EB.0020.0008.0126] # LATIN CAPITAL LETTER H WITH STROKE
017C      ; [.14AC.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
007A 0307 ; [.14AC.0020.0002.017C] # LATIN SMALL LETTER Z WITH DOT ABOVE
017B      ; [.14AC.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
005A 0307 ; [.14AC.0020.0008.017B] # LATIN CAPITAL LETTER Z WITH DOT ABOVE
ENTRY
};
