+{
# b-hook, d-hook, k-hook, y-hook don't require tailoring
   entry => <<'ENTRY', # for DUCET v5.2.0
0073 0068 ; [.1411.0020.0002.0073] # <LATIN SMALL LETTER S, LATIN SMALL LETTER H>
0053 0068 ; [.1411.0020.0007.0053] # <LATIN CAPITAL LETTER S, LATIN SMALL LETTER H>
0053 0048 ; [.1411.0020.0008.0053] # <LATIN CAPITAL LETTER S, LATIN CAPITAL LETTER H>
0074 0073 ; [.1434.0020.0002.0074] # <LATIN SMALL LETTER T, LATIN SMALL LETTER S>
0054 0073 ; [.1434.0020.0007.0054] # <LATIN CAPITAL LETTER T, LATIN SMALL LETTER S>
0054 0053 ; [.1434.0020.0008.0054] # <LATIN CAPITAL LETTER T, LATIN CAPITAL LETTER S>
0027 0079 ; [.14A8.0020.0002.01B4] # <APOSTROPHE, LATIN SMALL LETTER Y>
0027 0059 ; [.14A8.0020.0008.01B3] # <APOSTROPHE, LATIN CAPITAL LETTER Y>
ENTRY
};
